function [C]=ccfMax(X,maxlag)
% Determines the time-lagged correlation matrix.
% -------------------------------------------------------------------------
% Input
% 
% X: n x m data matrix with n the number of time points and m the number of
% metabolites.
%
% maxlag: maximum time lag. For each pair of variables, the cross 
% correlations for all time lags between -maxlag and +maxlag are calculated
% and the maximum of the absolute value of these cross correlations can be 
% found in the time-lagged correlation matrix.
% -------------------------------------------------------------------------
% Output
%
% C: m x m time-lagged correlation matrix
% -------------------------------------------------------------------------
% References
%
% Diana M. Hendrickx, Margriet M.W.B. Hendriks, Paul H.C. Eilers,
% Age K. Smilde and Huub C.J. Hoefsloot
% Reverse engineering of metabolic networks, a critical assessment.
% Mol. Biosyst., 2011, DOI: 10.1039/C0MB00083C
%
% Arkin, A. and J. Ross (1995). 
% Statistical Construction of Chemical-Reaction Mechanisms from Measured 
% Time-Series. 
% Journal of Physical Chemistry 99(3): 970-979.
% -------------------------------------------------------------------------

% Author
% Diana M. Hendrickx, 04 January 2011
% -------------------------------------------------------------------------
% Version 
% 7.8.1.347 (R2009a)
%
% PLS Toolbox 2.1. (function crosscor)
% -------------------------------------------------------------------------

[n,m]=size(X);

     for i=1:m
        for j=1:m
            crcor=crosscor(X(:,i),X(:,j),maxlag);
            C(i,j)=max(abs(crcor));
        end
     end

% -------------------------------------------------------------------------
% Copyright Notice
% This is a license to use and modify SOFTWARE & DATA
% produced by THE BIOSYSTEMS DATA ANALYSIS GROUP (BDA Group)
% OF THE UNIVERSITY OF AMSTERDAM
%
% If you use, modify or redistribute the SOFTWARE & DATA and/or
% your source modifications, you agree
%
% (i) to use the SOFTWARE & DATA and/or your source modifications
% solely as part of your research and not in any commercial
% product ;
%
% (ii) that the SOFTWARE & DATA and/or your source modifications
% will not be distributed for profit ;
%
% (iii) all copyright notices and this license note with the
% SOFTWARE & DATA are retained any redistribution of
% the SOFTWARE & DATA, or any portion thereof ;
%
% (iv) to indemnify, hold harmless, and defend the Biosystems
% Data Analysis Group of the University of Amsterdam
% from and against any claims or lawsuits that arise or
% result from the use of the SOFTWARE & DATA or your source
% modifications .
%
% (v) to properly reference the SOFTWARE & DATA when used in
% your research in any publication that may result from
% that research .
%
% Reserved Rights. The Biosystems Data Analysis Group of the
% University of Amsterdam retain title and all ownership
% rights to the SOFTWARE & DATA.
%
% Copyright 2010 Biosystems Data Analysis Group ;
% University of Amsterdam
%
            
    
   